summaryrefslogtreecommitdiffstats
path: root/src/com/vaadin/tests/tickets/Ticket2106.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/vaadin/tests/tickets/Ticket2106.java')
-rw-r--r--src/com/vaadin/tests/tickets/Ticket2106.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/com/vaadin/tests/tickets/Ticket2106.java b/src/com/vaadin/tests/tickets/Ticket2106.java
index 953ac84afb..8168e06154 100644
--- a/src/com/vaadin/tests/tickets/Ticket2106.java
+++ b/src/com/vaadin/tests/tickets/Ticket2106.java
@@ -12,8 +12,8 @@ public class Ticket2106 extends Application {
private static CustomizedSystemMessages msgs = new Application.CustomizedSystemMessages();
static {
- // We will forward the user to www.itmill.com when the session expires
- msgs.setSessionExpiredURL("http://www.itmill.com");
+ // We will forward the user to www.vaadin.com when the session expires
+ msgs.setSessionExpiredURL("http://www.vaadin.com");
msgs.setSessionExpiredMessage(null);
msgs.setSessionExpiredCaption(null);
}